@@ -9,7 +9,7 @@ from cosmoglobe.h5 import ChainVersion, PARAMETER_GROUP_NAME
 from cosmoglobe.h5._alms import unpack_alms_from_chain
 from cosmoglobe.h5._decorators import validate_key, validate_samples, unpack_alms
 from cosmoglobe.h5._exceptions import ChainFormatError, ChainSampleError
-from cosmoglobe.sky.components import COSMOGLOBE_COMPS
+from cosmoglobe.sky.components import SkyComponentLabel
 
 
 class Chain:
@@ -21,13 +21,13 @@ class Chain:
 
     def __init__(self, path: Union[str, Path], burn_in: Optional[int] = None) -> None:
         """Validate and initialize the Chain object.
-        
+
         Parameters
         ----------
         path
             Path to the chainfile.
         burn_in
-            Burn in sample. All samples prior to (and including) the burn 
+            Burn in sample. All samples prior to (and including) the burn
             in sample is discarded.
         """
 
@@ -51,7 +51,9 @@ class Chain:
 
             sampled_groups = list(file[samples[0]].keys())
             components = [
-                group for group in sampled_groups if group in COSMOGLOBE_COMPS
+                group
+                for group in sampled_groups
+                if group in [label.value for label in SkyComponentLabel]
             ]
 
             parameters: Dict[str, Dict[str, Any]] = {}
@@ -110,6 +112,21 @@ class Chain:
 
         return self._version
 
+    @property
+    def tree(self):
+        """Prints group and dataset structure of the chainfile."""
+
+        def print_attrs(name, _):
+            space = name.count("/") * "    "
+            path = name.split("/")
+            if path[0] not in ("000000", "parameters"):
+                return
+            item_name = path[-1]
+            print(space + item_name)
+
+        with h5py.File(self.path, "r") as file:
+            file.visititems(print_attrs)
+
     @overload
     def get(self, key: str, *, samples: Optional[range] = None) -> Any:
         ...
@@ -272,9 +289,14 @@ class Chain:
                 output += fill
             return output
 
+        if ".astropy/cache" in str(self.path):
+            name = "cached chainfile"
+        else:
+            name = self.path.name
+
         main_repr = "\n"
         main_repr += "-" * COL_LEN + "\n"
-        main_repr += center(self.path.name) + "\n"
+        main_repr += center(name) + "\n"
         main_repr += "-" * COL_LEN + "\n"
         main_repr += "\n"
 
