@@ -1,3 +1,6 @@
+class ModelNotFoundError(Exception):
+    """Raised when a model is not found in the registry."""
+
 class ComponentNotFoundError(Exception):
     """Raised if a component is missing from the model."""
 
@@ -8,3 +11,4 @@ class ComponentError(Exception):
 
 class NsideError(Exception):
     """Raised if there is an issue with the nside of a map."""
+
