@@ -1,8 +1,7 @@
 from astropy.units import Quantity
-import numpy as np
 
-from cosmoglobe.sky.base_components import DiffuseComponent
-from cosmoglobe.utils.functions import thermodynamical_to_brightness
+from cosmoglobe.sky._base_components import DiffuseComponent
+from cosmoglobe.sky.components import SkyComponentLabel
 
 
 class CMB(DiffuseComponent):
@@ -25,14 +24,13 @@ class CMB(DiffuseComponent):
     :math:`T_0 = 2.7255 \mathrm{K}` as of BP9.
     """
 
-    label = "cmb"
+    label = SkyComponentLabel.CMB
 
-    def __init__(self, amp: Quantity, freq_ref: Quantity) -> None:
-        """Initializing base class."""
+    def get_freq_scaling(self, *_) -> Quantity:
+        """See base class.
 
-        super().__init__(self.label, amp, freq_ref)
+        NOTE: The CMB amplitude is stored in units of uK_CMB where it is
+        constant over the sky.
+        """
 
-    def get_freq_scaling(self, freqs: Quantity) -> Quantity:  # type: ignore
-        """See base class."""
-
-        return np.expand_dims(thermodynamical_to_brightness(freqs), axis=0)
+        return Quantity(1)
